==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_sr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Кварови и грешке</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Опис</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Покрени</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Алт+C</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp; Помоћ</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;О</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>Zatvori</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Алт+Ц</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Неактиван</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Напредак</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Преостали:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Грешке:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Кварови:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Покретање:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Тест</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Изаберите назив теста:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Помоћ</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>О FreeCAD UnitTest програму</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest је део FreeCAD програма, и подржава писање јединица Тестови за сопствене модуле.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Унесите име објекта за звање који,када је позван,вратиће TestCase.Клик 'старт',и тест на тај начин произведен ће се покренути. 

Дупли клик на грешке у приказу стабла да би сте видели више информација о томе,укључујући и стог траг.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_sr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Кварови и грешке</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Опис</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Покрени</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Алт+C</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp; Помоћ</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;О</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>Zatvori</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Алт+Ц</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Неактиван</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Напредак</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Преостали:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Грешке:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Кварови:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Покретање:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Тест</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Изаберите назив теста:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Помоћ</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>О FreeCAD UnitTest програму</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest је део FreeCAD програма, и подржава писање јединица Тестови за сопствене модуле.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Унесите име објекта који се може позвати, који ће онда вратити TestCase.Клик 'старт', и ће се покренути. 

За више информација кликните двапут на грешку у приказу стабла.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation type="unfinished">Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation type="unfinished">Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</translation>
    </message>
  </context>
</TS>
